summaryrefslogtreecommitdiffstats
path: root/chrome/views/window.cc
diff options
context:
space:
mode:
authorben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-16 00:26:30 +0000
committerben@chromium.org <ben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-10-16 00:26:30 +0000
commit4d0bd1045bc0df8daea2a5626e73906cb074631b (patch)
tree6794b895e236b68c2f7de1163dfb1c554646364c /chrome/views/window.cc
parent7609533b68dcbeaa80bf712dd84726d1da8d3f8a (diff)
downloadchromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.zip
chromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.tar.gz
chromium_src-4d0bd1045bc0df8daea2a5626e73906cb074631b.tar.bz2
Rename ViewContainer to Container and HWNDViewContainer to ContainerWin.
http://crbug.com/3430 Review URL: http://codereview.chromium.org/7376 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@3441 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/views/window.cc')
-rw-r--r--chrome/views/window.cc30
1 files changed, 14 insertions, 16 deletions
diff --git a/chrome/views/window.cc b/chrome/views/window.cc
index 78df878..4c9de42 100644
--- a/chrome/views/window.cc
+++ b/chrome/views/window.cc
@@ -117,7 +117,7 @@ void Window::Close() {
if (client_view_->CanClose()) {
SaveWindowPosition();
RestoreEnabledIfNecessary();
- HWNDViewContainer::Close();
+ ContainerWin::Close();
// If the user activates another app after opening us, then comes back and
// closes us, we want our owner to gain activation. But only if the owner
// is visible. If we don't manually force that here, the other app will
@@ -259,7 +259,7 @@ gfx::Size Window::GetLocalizedContentsSize(int col_resource_id,
// Window, protected:
Window::Window(WindowDelegate* window_delegate)
- : HWNDViewContainer(),
+ : ContainerWin(),
focus_on_creation_(true),
window_delegate_(window_delegate),
non_client_view_(NULL),
@@ -286,7 +286,7 @@ void Window::Init(HWND parent, const gfx::Rect& bounds) {
// return NULL.
owning_hwnd_ = parent;
// We call this after initializing our members since our implementations of
// assorted HWNDViewContainer functions may be called during initialization.
is_modal_ = window_delegate_->IsModal();
if (is_modal_)
BecomeModal();
@@ -297,7 +297,7 @@ void Window::Init(HWND parent, const gfx::Rect& bounds) {
if (window_ex_style() == 0)
set_window_ex_style(CalculateWindowExStyle());
- HWNDViewContainer::Init(parent, bounds, true);
+ ContainerWin::Init(parent, bounds, true);
win_util::SetWindowUserData(GetHWND(), this);
std::wstring window_title = window_delegate_->GetWindowTitle();
@@ -318,9 +318,9 @@ void Window::SetClientView(ClientView* client_view) {
client_view_ = client_view;
if (non_client_view_) {
// This will trigger the ClientView to be added by the non-client view.
- HWNDViewContainer::SetContentsView(non_client_view_);
+ ContainerWin::SetContentsView(non_client_view_);
} else {
- HWNDViewContainer::SetContentsView(client_view_);
+ ContainerWin::SetContentsView(client_view_);
}
}
@@ -352,7 +352,7 @@ void Window::RunSystemMenu(const CPoint& point) {
}
///////////////////////////////////////////////////////////////////////////////
// Window, HWNDViewContainer overrides:
void Window::OnActivate(UINT action, BOOL minimized, HWND window) {
if (action == WA_INACTIVE)
@@ -363,17 +363,15 @@ LRESULT Window::OnAppCommand(HWND window, short app_command, WORD device,
int keystate) {
// We treat APPCOMMAND ids as an extension of our command namespace, and just
// let the delegate figure out what to do...
- if (!window_delegate_->ExecuteWindowsCommand(app_command)) {
- return HWNDViewContainer::OnAppCommand(window, app_command, device,
- keystate);
- }
+ if (!window_delegate_->ExecuteWindowsCommand(app_command))
+ return ContainerWin::OnAppCommand(window, app_command, device, keystate);
return 0;
}
void Window::OnCommand(UINT notification_code, int command_id, HWND window) {
if (!window_delegate_->ExecuteWindowsCommand(command_id))
- HWNDViewContainer::OnCommand(notification_code, command_id, window);
+ ContainerWin::OnCommand(notification_code, command_id, window);
}
void Window::OnDestroy() {
@@ -382,7 +380,7 @@ void Window::OnDestroy() {
window_delegate_ = NULL;
}
RestoreEnabledIfNecessary();
- HWNDViewContainer::OnDestroy();
+ ContainerWin::OnDestroy();
}
LRESULT Window::OnEraseBkgnd(HDC dc) {
@@ -396,7 +394,7 @@ LRESULT Window::OnNCActivate(BOOL active) {
return DefWindowProc(GetHWND(), WM_NCACTIVATE, TRUE, 0);
}
// Otherwise just do the default thing.
- return HWNDViewContainer::OnNCActivate(active);
+ return ContainerWin::OnNCActivate(active);
}
LRESULT Window::OnNCHitTest(const CPoint& point) {
@@ -422,14 +420,14 @@ LRESULT Window::OnNCHitTest(const CPoint& point) {
void Window::OnNCLButtonDown(UINT ht_component, const CPoint& point) {
if (non_client_view_ && ht_component == HTSYSMENU)
RunSystemMenu(non_client_view_->GetSystemMenuPoint());
- HWNDViewContainer::OnNCLButtonDown(ht_component, point);
+ ContainerWin::OnNCLButtonDown(ht_component, point);
}
void Window::OnNCRButtonDown(UINT ht_component, const CPoint& point) {
if (ht_component == HTCAPTION || ht_component == HTSYSMENU) {
RunSystemMenu(point);
} else {
- HWNDViewContainer::OnNCRButtonDown(ht_component, point);
+ ContainerWin::OnNCRButtonDown(ht_component, point);
}
}
@@ -286,7 +286,7 @@ void Window::Init(HWND parent, const gfx::Rect& bounds) {
owning_hwnd_ = parent;
// We call this after initializing our members since our implementations of
- // assorted HWNDViewContainer functions may be called during initialization.
+ // assorted ContainerWin functions may be called during initialization.
is_modal_ = window_delegate_->IsModal();
if (is_modal_)
@@ -352,7 +352,7 @@ void Window::RunSystemMenu(const CPoint& point) {
}
///////////////////////////////////////////////////////////////////////////////
-// Window, HWNDViewContainer overrides:
+// Window, ContainerWin overrides:
void Window::OnActivate(UINT action, BOOL minimized, HWND window) {
if (action == WA_INACTIVE)